import { ResponseContext, RequestContext, HttpFile } from '../http/http';
import * as models from '../models/all';
import { Configuration} from '../configuration'

import { BaseUser } from '../models/BaseUser';
import { CreateAccountRequest } from '../models/CreateAccountRequest';
import { CreateAccountRequestAllOf } from '../models/CreateAccountRequestAllOf';
import { ErrorDetails } from '../models/ErrorDetails';
import { ErrorResponse } from '../models/ErrorResponse';
import { ErrorResponses } from '../models/ErrorResponses';
import { LoginRequest } from '../models/LoginRequest';
import { PageProperties } from '../models/PageProperties';
import { Role } from '../models/Role';
import { TokenResponse } from '../models/TokenResponse';

import { ObservableAuthApi } from "./ObservableAPI";
import { AuthApiRequestFactory, AuthApiResponseProcessor} from "../apis/AuthApi";

export interface AuthApiAccountLoginRequest {
    /**
     * 
     * @type LoginRequest
     * @memberof AuthApiaccountLogin
     */
    loginRequest?: LoginRequest
}

export interface AuthApiCreateAccountRequest {
    /**
     * 
     * @type CreateAccountRequest
     * @memberof AuthApicreateAccount
     */
    createAccountRequest?: CreateAccountRequest
}

export class ObjectAuthApi {
    private api: ObservableAuthApi

    public constructor(configuration: Configuration, requestFactory?: AuthApiRequestFactory, responseProcessor?: AuthApiResponseProcessor) {
        this.api = new ObservableAuthApi(configuration, requestFactory, responseProcessor);
    }

    /**
     *  User Account Login 
     * Login to an existing user account.
     * @param param the request object
     */
    public accountLogin(param: AuthApiAccountLoginRequest = {}, options?: Configuration): Promise<TokenResponse> {
        return this.api.accountLogin(param.loginRequest,  options).toPromise();
    }

    /**
     *  Email address must be unique. After successful registration, an email is sent to verify the account. 
     * Creates a new user account.
     * @param param the request object
     */
    public createAccount(param: AuthApiCreateAccountRequest = {}, options?: Configuration): Promise<void> {
        return this.api.createAccount(param.createAccountRequest,  options).toPromise();
    }

}
