import { ResponseContext, RequestContext, HttpFile } from '../http/http';
import * as models from '../models/all';
import { Configuration} from '../configuration'

import { BaseUser } from '../models/BaseUser';
import { CreateAccountRequest } from '../models/CreateAccountRequest';
import { CreateAccountRequestAllOf } from '../models/CreateAccountRequestAllOf';
import { ErrorDetails } from '../models/ErrorDetails';
import { ErrorResponse } from '../models/ErrorResponse';
import { ErrorResponses } from '../models/ErrorResponses';
import { LoginRequest } from '../models/LoginRequest';
import { PageProperties } from '../models/PageProperties';
import { Role } from '../models/Role';
import { TokenResponse } from '../models/TokenResponse';
import { ObservableAuthApi } from './ObservableAPI';

import { AuthApiRequestFactory, AuthApiResponseProcessor} from "../apis/AuthApi";
export class PromiseAuthApi {
    private api: ObservableAuthApi

    public constructor(
        configuration: Configuration,
        requestFactory?: AuthApiRequestFactory,
        responseProcessor?: AuthApiResponseProcessor
    ) {
        this.api = new ObservableAuthApi(configuration, requestFactory, responseProcessor);
    }

    /**
     *  User Account Login 
     * Login to an existing user account.
     * @param loginRequest 
     */
    public accountLogin(loginRequest?: LoginRequest, _options?: Configuration): Promise<TokenResponse> {
        const result = this.api.accountLogin(loginRequest, _options);
        return result.toPromise();
    }

    /**
     *  Email address must be unique. After successful registration, an email is sent to verify the account. 
     * Creates a new user account.
     * @param createAccountRequest 
     */
    public createAccount(createAccountRequest?: CreateAccountRequest, _options?: Configuration): Promise<void> {
        const result = this.api.createAccount(createAccountRequest, _options);
        return result.toPromise();
    }


}



